@@ -6,4 +6,4 @@ def sqrt(x):
 	if type(x) == float:
 		y = math.sqrt(x)
 		z = round(y)
-		print(z)
\ No newline at end of file
+		print(int(z))
\ No newline at end of file
